#
# spec file for package deepin-desktop-base
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _version 2022.07.26

Name:           deepin-desktop-base
Version:        20.6
Release:        bp156.2.1
Summary:        Base component for Deepin
License:        GPL-3.0-or-later
Group:          System/GUI/Other
URL:            https://github.com/linuxdeepin/deepin-desktop-base
Requires:       distribution-logos
Source0:        https://github.com/linuxdeepin/deepin-desktop-base/archive/%{_version}/%{name}-%{_version}.tar.gz
# PATCH-FIX-OPENSUSE do-not-installl-os-version.patch hillwood@opensuse.org - Don't install deepin os information
Patch0:         do-not-installl-os-version.patch
# PATCH-FIX-OPENSUSE add-suse-info.patch hillwood@opensuse.org - Use openSUSE information
Patch1:         add-suse-info.patch
Patch2:         desktop-version-fallback.patch

%description
This package provides some components for the Deepin desktop environment:
Deepin logo, desktop version, login screen background image, and
language information.

%prep
%autosetup -p1 -n %{name}-%{_version}

# Remove Deepin distro's lsb-release
# Don't override systemd timeouts
# Remove apt-specific templates
sed -i -E '/lsb-release|systemd|apt/d' Makefile

# Fix data path
sed -i 's|/usr/lib|%{_datadir}|' Makefile

%build
%make_build

%install
%make_install
install -Dm644 distribution.info %{buildroot}%{_datadir}/deepin/
%ifarch ppc ppc64 ppc64le s390 s390x
install -d %{buildroot}%{_datadir}/deepin-manual/manual-assets/application/
%endif

# Make a symlink for deepin-version
ln -sfv %{_datadir}/deepin/desktop-version %{buildroot}/etc/deepin-version

%files
%doc CHANGELOG.md
%license LICENSE
%config(noreplace) %{_sysconfdir}/appstore.json
%{_sysconfdir}/*-version
%dir %{_datadir}/deepin/
%ifarch ppc ppc64 ppc64le s390 s390x
%dir %{_datadir}/deepin-manual/
%dir %{_datadir}/deepin-manual/manual-assets
%dir %{_datadir}/deepin-manual/manual-assets/application
%endif
%{_datadir}/deepin/distribution.info
%{_datadir}/deepin/*-version
%dir %{_datadir}/distro-info
%dir %{_datadir}/i18n
%{_datadir}/i18n/i18n_dependent.json
%{_datadir}/i18n/language_info.json

%changelog
* Mon Aug 29 2022 Hillwood Yang <hillwood@opensuse.org>
- Update version to 2022.07.26, Deepin version is 20.6
* Fri Apr 15 2022 Hillwood Yang <hillwood@opensuse.org>
- Update version to 2022.03.07, Deepin version is 20.5
* Mon Jan 31 2022 Hillwood Yang <hillwood@opensuse.org>
- Update version to 2021.11.08, Deepin version is 20.3
* Thu Jul 29 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 2021.06.16, Deepin version is 20.2.2
* Thu Jul  1 2021 Andreas Schwab <schwab@suse.de>
- desktop-version-fallback.patch: add fallback for desktop-version
* Thu Jun  3 2021 Hillwood Yang <hillwood@opensuse.org>
- Package deepin-manual directories for ppc ppc64 ppc64le s390 s390x
* Tue Apr 27 2021 Hillwood Yang <hillwood@opensuse.org>
- Install distribution.info
* Sun Apr 25 2021 Hillwood Yang <hillwood@opensuse.org>
- Update do-not-installl-os-version.patch, fix build on ppc64
* Thu Apr 15 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 2021.3.10, Deepin version is 20.2
- Update add-suse-info.patch for distribution.info
* Mon Feb 15 2021 Hillwood Yang <hillwood@opensuse.org>
- Add do-not-installl-os-version.patch. Don't install deepin os information
* Tue Feb  9 2021 Jan Engelhardt <jengelh@inai.de>
- Remove obsolete build recipe constructs.
* Tue Aug 13 2019 Hillwood Yang <hillwood@opensuse.org>
- Use suse information in lightdm-deepin-greeter (add-suse-info.patch)
* Sat Jul 20 2019 Hillwood Yang <hillwood@opensuse.org>
- Update version to 2019.07.10, Deepin version is 15.11
* Fri Apr 19 2019 Hillwood Yang <hillwood@opensuse.org>
- Update version to 2019.04.03, Deepin version is 15.10
* Fri Mar 23 2018 hillwood@opensuse.org
- Update version to 2018.03.19
  * Add dde-desktop-watermask.json and watermark_logo.svg
* Sat Dec  2 2017 hillwood@opensuse.org
- Update to 15.5 (2017.11.1)
  * Remove depends friendly-recovery
  * Update /etc/lsb-release
* Sun Nov 12 2017 hillwood@opensuse.org
- Update to 15.5 Beta (2016.13.2)
  * Add .clog.toml
- Add Group tag.
* Tue Oct  3 2017 sensor.wen@gmail.com
- Initial package.
